{% for result in results %}
<div class="result">
    <div class="result__heading">
        <div class="result__heading__left">
            {% if result['resultStatus'] == 'TIMEOUT' %}
            <img src="assets/icon-timeout.svg" alt="TIMEOUT" />
            {% elif result['resultStatus'] == 'ERROR' %}
            <img src="assets/icon-fail.svg" alt="ERROR" />
            {% endif %}        

            <div class="result__heading__title--failed">{{ get_result_title(result) }}</div>
        </div>

        <div class="result__heading__right">
            <div class="result__heading__theme">{{ result['themes'][0] | capitalize }}</div>
        </div>
    </div>
</div>
{% endfor %}