<!doctype html>
<html lang="no">

<head>
    <meta charset="utf-8">
    <link rel="stylesheet" href="assets/styles.css" />
    <title>DOK-analyse</title>
</head>

<body>
    {% block body %}{% endblock %}
</body>

</html>